@@ -286,15 +286,20 @@ class RuleCoombs(Rule):
     'On The Complexity of Manipulating Elections', Tom Coleman and Vanessa Teague, 2007.
     """
 
+    full_name = 'Coombs'
+    abbreviation = 'Coo'
+
+    options_parameters = Rule.options_parameters.copy()
+    options_parameters.update({
+        'im_option': {'allowed': ['fast', 'exact'], 'default': 'fast'},
+        'tm_option': {'allowed': ['exact'], 'default': 'exact'},
+        'um_option': {'allowed': ['fast', 'exact'], 'default': 'fast'},
+        'icm_option': {'allowed': ['exact'], 'default': 'exact'},
+        'cm_option': {'allowed': ['fast', 'exact'], 'default': 'fast'},
+    })
+
     def __init__(self, **kwargs):
         super().__init__(
-            options_parameters={
-                'im_option': {'allowed': ['fast', 'exact'], 'default': 'fast'},
-                'tm_option': {'allowed': ['exact'], 'default': 'exact'},
-                'um_option': {'allowed': ['fast', 'exact'], 'default': 'fast'},
-                'icm_option': {'allowed': ['exact'], 'default': 'exact'},
-                'cm_option': {'allowed': ['fast', 'exact'], 'default': 'fast'},
-            },
             with_two_candidates_reduces_to_plurality=True, is_based_on_rk=True,
             precheck_um=False, precheck_icm=False,
             log_identity="COOMBS", **kwargs
